part of 'land_property_assessment_bloc.dart';

class LandPropertyAssessmentState extends Equatable {
  const LandPropertyAssessmentState();

  @override
  List<Object> get props => [];
}

class LandPropertyAssessmentInitial extends LandPropertyAssessmentState {
  @override
  List<Object> get props => [];
}

class LandPropertyAssessmentLoaded extends LandPropertyAssessmentState {
  final List<LandPropertyAssessment> landPropertyAssessment;

  const LandPropertyAssessmentLoaded({required this.landPropertyAssessment});
  @override
  List<Object> get props => [landPropertyAssessment];
}

class LoadSpecificLandPropertyAssessment extends LandPropertyAssessmentState {
  final LandPropertyAssessment landPropertyAssessment;

  const LoadSpecificLandPropertyAssessment(
      {required this.landPropertyAssessment});
  @override
  List<Object> get props => [landPropertyAssessment];
}

class ShowLandPropertyAssessmentcreen extends LandPropertyAssessmentState {}

class LandPropertyAssessmentErrorState extends LandPropertyAssessmentState {
  const LandPropertyAssessmentErrorState(this.error);
  final String error;

  @override
  List<Object> get props => [error];
}

class LandPropertyAssessmentDeletedState extends LandPropertyAssessmentState {
  final bool success;
  const LandPropertyAssessmentDeletedState({required this.success});
  @override
  List<Object> get props => [success];
}
